[Scummvm-cvs-logs] CVS: scummvm/backends/sdl sdl-common.h,1.17,1.18 sdl-common.cpp,1.35,1.36

Jonathan Gray khalek at users.sourceforge.net
Fri Mar 7 22:53:06 CET 2003


Update of /cvsroot/scummvm/scummvm/backends/sdl
In directory sc8-pr-cvs1:/tmp/cvs-serv21641

Modified Files:
	sdl-common.h sdl-common.cpp 
Log Message:
change RBG to RGB which follows the argument order and hence makes more sense...

Index: sdl-common.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/backends/sdl/sdl-common.cpp,v
retrieving revision 1.35
retrieving revision 1.36
diff -u -d -r1.35 -r1.36
--- sdl-common.cpp	6 Mar 2003 21:45:10 -0000	1.35
+++ sdl-common.cpp	8 Mar 2003 06:52:44 -0000	1.36
@@ -925,7 +925,7 @@
 				*bak++ = *dst;
 				color = *src++;
 				if (color != 0xFF)	// 0xFF = transparent, don't draw
-					*dst = RBGToColor(_currentPalette[color].r, _currentPalette[color].g, _currentPalette[color].b);
+					*dst = RGBToColor(_currentPalette[color].r, _currentPalette[color].g, _currentPalette[color].b);
 				dst++;
 				width--;
 			}
@@ -1230,10 +1230,10 @@
 	SDL_UnlockSurface(_tmpscreen);
 }
 
-int16 OSystem_SDL_Common::RBGToColor(uint8 r, uint8 g, uint8 b) {
+int16 OSystem_SDL_Common::RGBToColor(uint8 r, uint8 g, uint8 b) {
 	return SDL_MapRGB(_tmpscreen->format, r, g, b);
 }
 
-void OSystem_SDL_Common::colorToRBG(int16 color, uint8 &r, uint8 &g, uint8 &b) {
+void OSystem_SDL_Common::colorToRGB(int16 color, uint8 &r, uint8 &g, uint8 &b) {
 	SDL_GetRGB(color, _tmpscreen->format, &r, &g, &b);
 }





More information about the Scummvm-git-logs mailing list
Index: sdl-common.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/backends/sdl/sdl-common.h,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -d -r1.17 -r1.18
--- sdl-common.h	6 Mar 2003 21:45:12 -0000	1.17
+++ sdl-common.h	8 Mar 2003 06:52:44 -0000	1.18
@@ -117,9 +117,9 @@
 	virtual int16 get_height();
 	virtual int16 get_width();
 
-	// Methods that convert RBG to/from colors suitable for the overlay.
-	virtual int16 RBGToColor(uint8 r, uint8 g, uint8 b);
-	virtual void colorToRBG(int16 color, uint8 &r, uint8 &g, uint8 &b);
+	// Methods that convert RGB to/from colors suitable for the overlay.
+	virtual int16 RGBToColor(uint8 r, uint8 g, uint8 b);
+	virtual void colorToRGB(int16 color, uint8 &r, uint8 &g, uint8 &b);
 
 	static OSystem *create(int gfx_mode, bool full_screen);
 
